Crate ts_bitset

Crate ts_bitset 

Provides Bitset256, a compact, efficient, non-allocating 256-entry bitset implementation supporting bitwise operations, iteration over set bits, and rank calculation.

Based on the package of the same name in golang’s bart.

Structs

Bitset
A compact, efficient, non-allocating 256-entry bitset supporting bitwise operations, iteration over set bits, and rank calculation.

Constants

RANK_LUT_SIZE
The size of the Bitset256::rank lookup table in bytes.

Traits

BitsetDyn
Subset of bitset ops that support dynamic dispatch.
BitsetStatic
Subset of bitset ops that do not support dynamic dispatch.
ConstBitset
A bitset that supports const-construction and reporting of bit length.

Type Aliases

Bitset256
Alias for a 256-bit bitset, which conveniently covers a whole u8.